<?php
// SSH LOGIN WITH PASSWORD CONFIG WIZARD
//
// Copyright (c) 2010 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: ssh-expect.inc.php 1378 2014-07-15 16:06:44Z swilkerson $

include_once(dirname(__FILE__) . '/../configwizardhelper.inc.php');


/**
 * Class ssh_expect_configwizard_textbox
 */
class ssh_expect_configwizard_textbox
{
    const textboxf = '	<tr>
	<td valign="top">
	<label>%s:</label><br class="nobr" />
	</td>
	<td>
<input type="%s" size="%s" name="%s" id="%s" value="%s" class="textfield"%s/><br class="nobr" />
	%s<br><br>
	</td>

	</tr>';
    const hiddenf = '<input type="hidden" name="%s" value="%s">';

    var $label = 'An option';
    var $type = 'text';
    var $size = 30;
    var $name = 'option';
    var $value = '';
    var $extopts = '';
    var $desc = 'Fill this in to set your option.';
    var $output;
    var $mode = -1;
    var $gomode = -1;

    /**
     * @param $label
     * @param $type
     * @param $size
     * @param $name
     * @param $extopts
     * @param $desc
     * @param $gomode
     */
    function __construct($label, $type, $size, $name, $extopts,
                         $desc, $gomode)
    {
        if ($label != '') $this->label = $label;
        if ($type != '') $this->type = $type;
        if ($size != '') $this->size = $size;
        if ($name != '') $this->name = $name;
        if ($extopts != '') $this->extopts = $extopts;
        if ($desc != '') $this->desc = $desc;
        if ($gomode != '') $this->gomode = $gomode;
    }

    /**
     * @param $inargs
     */
    public function parseinargs($inargs)
    {
        $this->value = grab_array_var($inargs, $this->name, $this->value);
    }

    /**
     * @param $output
     * @param $mode
     */
    public function html(&$output, $mode)
    {
        if ($output != '' || $output === '') $this->output =& $output;
        if ($mode != '') $this->mode = $mode;

        $output .= $this->mode === $this->gomode ?
            sprintf(self::textboxf,
                htmlentities($this->label), htmlentities($this->type),
                htmlentities($this->size), htmlentities($this->name),
                htmlentities($this->label), htmlentities($this->value),
                $this->extopts, htmlentities($this->desc)) :
            sprintf(self::hiddenf,
                htmlentities($this->name), htmlentities($this->value));
    }
}

/**
 * Class ssh_expect_configwizard_stopstart_table
 */
class ssh_expect_configwizard_stopstart_table
{
    const tablbrkf = '

	</table>


	<div class="sectionTitle">%s</div>


	<table>

';

    var $label = 'Section Title';
    var $name = 'unused-html-tag-name';
    var $mode = -1;
    var $gomode = -1;

    /**
     * @param $label
     * @param $gomode
     */
    function __construct($label, $gomode)
    {
        if ($label != '') $this->label = $label;
        if ($gomode != '') $this->gomode = $gomode;
    }

    /**
     * @param $inargs
     */
    public function parseinargs($inargs)
    {
    }

    /**
     * @param $output
     * @param $mode
     */
    public function html(&$output, $mode)
    {
        if ($output != '' || $output === '') $this->output =& $output;
        if ($mode != '') $this->mode = $mode;

        $output .= $this->mode === $this->gomode ?
            sprintf(self::tablbrkf, htmlentities($this->label)) : '';
    }
}

/**
 * Class ssh_expect_object_configwizard
 */
class ssh_expect_object_configwizard
{

    const name = 'ssh-expect';
    const type = CONFIGWIZARD_TYPE_MONITORING;
    const description = 'Monitor the availability and response times of SSH logins.';
    const displaytitle = 'SSH Login';
//	const mainfunction = 'ssh_expect__configwizard_func';
    const previewimage = 'ssh-expect.png';

    public $mode = '';
    public $inargs = null;
    public $outargs;
    public $result;
    public $args;

    public function configwizard_init()
    {

        $this->args = array(
            CONFIGWIZARD_NAME => self::name,
            CONFIGWIZARD_VERSION => "1.4",
            CONFIGWIZARD_TYPE => self::type,
            CONFIGWIZARD_DESCRIPTION => self::description,
            CONFIGWIZARD_DISPLAYTITLE => self::displaytitle,
            CONFIGWIZARD_FUNCTION => CONFIGWIZARD_API_VERSION <= 2 ? 'ssh_expect_static_configwizard_func' : 'ssh_expect_static_configwizard::configwizard_func',
            CONFIGWIZARD_PREVIEWIMAGE => self::previewimage,
        );

        $this->textboxes = array(
            new ssh_expect_configwizard_textbox('Address', 'text', '30', 'address', '',
                gettext('The IP address or FQDNS name of the device or server associated') . '<br>' .
                gettext('with this SSH server.'), CONFIGWIZARD_MODE_GETSTAGE1HTML),
            new ssh_expect_configwizard_textbox('Host Name', 'text', '20', 'hostname', '',
                gettext('The name you\'d like to have associated with this SSH server.'),
                CONFIGWIZARD_MODE_GETSTAGE2HTML),
            new ssh_expect_configwizard_stopstart_table('Login Details',
                CONFIGWIZARD_MODE_GETSTAGE2HTML),
            new ssh_expect_configwizard_textbox('Username', 'text', '20', 'username',
                '', gettext('The username used to login via SSH.'),
                CONFIGWIZARD_MODE_GETSTAGE2HTML),
            new ssh_expect_configwizard_textbox('Password', 'password', '20', 'password',
                '', gettext('The password used to login via SSH.'),
                CONFIGWIZARD_MODE_GETSTAGE2HTML),
            new ssh_expect_configwizard_stopstart_table('Service Details',
                CONFIGWIZARD_MODE_GETSTAGE2HTML),
            new ssh_expect_configwizard_textbox('Paws4Login', 'text', '3', 'opt_s', '',
                gettext('The timeout value used during login, also used as a all through') . '<br>' .
                gettext('for the MOTD and prompt.'),
                CONFIGWIZARD_MODE_GETSTAGE2HTML),
            new ssh_expect_configwizard_textbox('Paws4Commands', 'text', '3', 'opt_r',
                '', gettext('Timeout used as a fall through for command output.'),
                CONFIGWIZARD_MODE_GETSTAGE2HTML),
            new ssh_expect_configwizard_textbox('Commands', 'text', '20', 'opt_d',
                '', gettext('The commands to send separated by \';\'s.'),
                CONFIGWIZARD_MODE_GETSTAGE2HTML),
            new ssh_expect_configwizard_textbox('LoginMatch', 'text', '20', 'opt_e',
                '', gettext('A string to match typically from the MOTD.  The stopwatch starts at first SYN and ends after the Paws4Login timeout and a match on this string'),
                CONFIGWIZARD_MODE_GETSTAGE2HTML),
        );

    }

    /**
     * @return bool
     */
    private function check_installation()
    {
        $install_file = dirname(__FILE__) . '/ssh-expect.installed';
        //echo "INSTALL FILE: $install_file<BR>";
        if (file_exists($install_file)) {
            //echo "INSTALLED!<BR>";
            return true;
        }
        //echo "NOT INSTALLED...<BR>";
        return false;
    }

    var $textboxes = array();

    private function parseinargs()
    {
        // get variables that were passed to us
        foreach ($this->textboxes as $textbox) {
            $textbox->parseinargs($this->inargs);
        }

        if ($this->textboxes[1]->value == '') {
            $ha = @gethostbyaddr($this->textboxes[0]->value);
            $this->textboxes[1]->value = $ha == '' ?
                $this->textboxes[0]->value : $ha;
        }
    }

    /**
     * @param $output
     */
    function getstaget1html(&$output)
    {

        $this->parseinargs();

        $output = '';

        if ($this->check_installation() == false) {
            $output .= '
			<div class="sectionTitle">' . gettext('Installation Required') . '</div>
			
			<div style="color: red;"><b>' . gettext('NOTE') . ':</b> ' . gettext('This configuration wizard requires some additional software components to be installed on your Nagios XI system before it can be used.  The wizard has detected that you have not yet completed the necessary installation steps.  Follow the steps below to install the required components before proceeding') . ':</div>
			<p>
			<ol>
			<li>' . gettext('Login to your Nagios XI server as the root user') . '
			<li>' . gettext('Complete the installation by executing the following commands') . ':
			</ol>
			</p>
<pre>
cd ' . dirname(__FILE__) . '/scripts
chmod a+x ./install.sh; ./install.sh
</pre>
<br>
			';
        } else {

            $output .= '

	<div class="sectionTitle">' . gettext('SSH Server') . '</div>


	<table>

';
            foreach ($this->textboxes as $textbox) {
                $textbox->html($output, $this->mode);
            }
            $output .= '

	</table>

';
        }
    }

    /**
     * @param $output
     */
    function validatestage1data(&$output)
    {
        $this->parseinargs();

        // check for errors
        $errors = 0;
        $errmsg = array();
        if ($this->check_installation() == false) {
            $errmsg[$errors++] = gettext('Required components are not installed.');
        } else {
            if (have_value(grab_array_var($this->inargs, "address")) == false)
                $errmsg[$errors++] = gettext('No address specified.');
        }

        if ($errors > 0) {
            $this->outargs[CONFIGWIZARD_ERROR_MESSAGES] = $errmsg;
            $this->result = 1;
        }

    }

    /**
     * @param $output
     */
    function getstaget2html(&$output)
    {
        $this->parseinargs();

        $output = '

	<div class="sectionTitle">' . gettext('SSH Server') . '</div>


	<table>
';
        foreach ($this->textboxes as $textbox) {
            switch ($textbox->name) {
                case 'address':
                    $tmp = $textbox->extopts;
                    $textbox->extopts .= gettext(' disabled');
                    $textbox->html($output,
                        CONFIGWIZARD_MODE_GETSTAGE1HTML);
                    $textbox->extopts = $tmp;
                    unset($tmp);
                    $textbox->html($output, $this->mode);
                    break;
                default:
                    $textbox->html($output, $this->mode);
            }
        }

        $output .= '

	</table>


';
    }

    /**
     * @param $output
     */
    function validatestage2data(&$output)
    {
        $this->parseinargs();

        // check for errors
        $errors = 0;
        $errmsg = array();
        if (have_value(grab_array_var($this->inargs, "hostname")) == false)
            $errmsg[$errors++] = gettext('No hostname specified.');
        else if (is_valid_host_name(grab_array_var($this->inargs, "address")) == false)
            $errmsg[$errors++] = gettext('Invalid host name.');
        if (have_value(grab_array_var($this->inargs, "username")) == false)
            $errmsg[$errors++] = gettext('No username specified.');
        if (have_value(grab_array_var($this->inargs, "password")) == false)
            $errmsg[$errors++] = gettext('No password specified.');

        if ($errors > 0) {
            $this->outargs[CONFIGWIZARD_ERROR_MESSAGES] = $errmsg;
            $this->result = 1;
        }

    }

    /**
     * @param $output
     */
    function getstaget3html(&$output)
    {
        $this->parseinargs();
        $output = '

	<div class="sectionTitle">gettext(SSH Check Options)</div>


	<table>
';
        foreach ($this->textboxes as $textbox) {
            $textbox->html($output, $this->mode);
        }
        $output .= '

	</table>


';

    }

    /**
     * @param $output
     */
    function validatestage3data(&$output)
    {

    }

    /**
     * @param $output
     */
    function getfinalstagehtml(&$output)
    {

    }

    function getobjects()
    {
        $this->parseinargs();

        /*
        echo "SERVICES<BR>";
        print_r($services);
        echo "<BR>";
        echo "SERVICEARGS<BR>";
        print_r($serviceargs);
        echo "<BR>";
        */

        // save data for later use in re-entrance
        $meta_arr = array();
        $meta_arr['hostname'] = grab_array_var($this->inargs, "hostname");
        $meta_arr['address'] = grab_array_var($this->inargs, "address");
        $meta_arr['username'] = grab_array_var($this->inargs, "username");
        $meta_arr['password'] = grab_array_var($this->inargs, "password");
        $meta_arr['opt_d'] = grab_array_var($this->inargs, "opt_d");
        $meta_arr['opt_e'] = grab_array_var($this->inargs, "opt_e");
        $meta_arr['opt_s'] = grab_array_var($this->inargs, "opt_s");
        $meta_arr['opt_r'] = grab_array_var($this->inargs, "opt_r");
        save_configwizard_object_meta(self::name, $meta_arr['hostname'], '', $meta_arr);

        $objs = array();

        if (!host_exists($this->textboxes[1]->value)) {
            $objs[] = array(
                "type" => OBJECTTYPE_HOST,
                "use" => "xiwizard_generic_host",
                "host_name" => $meta_arr['hostname'],
                "address" => $meta_arr['address'],
                "icon_image" => self::previewimage,
                "statusmap_image" => self::previewimage,
                "_xiwizard" => self::name,
            );
        }

        $pluginopts = $meta_arr['username'] . '!' . $meta_arr['password'] . '!';
        if ($meta_arr['opt_d'] != "") $pluginopts .= "-d '" . $meta_arr['opt_d'] . "' ";
        if ($meta_arr['opt_e'] != "") $pluginopts .= "-e '" . $meta_arr['opt_e'] . "' ";
        if ($meta_arr['opt_s'] != "") $pluginopts .= "-s " . $meta_arr['opt_s'] . " ";
        if ($meta_arr['opt_r'] != "") $pluginopts .= "-r " . $meta_arr['opt_r'] . " ";


        $objs[] = array(
            "type" => OBJECTTYPE_SERVICE,
            "host_name" => $meta_arr['hostname'],
            "use" => "xiwizard_generic_service",
            "service_description" => "SSH Login Service",
            "check_command" => "check_ssh_expect!" . $pluginopts,
            "icon_image" => self::previewimage,
            "_xiwizard" => self::name,
        );

        //echo "OBJECTS:<BR>";
        //print_r($objs);
        //exit();

        // return the object definitions to the wizard
        $this->outargs[CONFIGWIZARD_NAGIOS_OBJECTS] = $objs;

    }

    /**
     * @param string $mode
     * @param null   $inargs
     * @param        $outargs
     * @param        $result
     *
     * @return string
     */
    public function configwizard_func($mode = "",
                                      $inargs = null, &$outargs, &$result)
    {

        // Save away arguments as properties.
        $this->mode = $mode;
        $this->inargs = $inargs;
        $this->outargs =& $outargs;
        $this->result =& $result;

        // initialize return code and output
        $this->result = 0;
        $output = '';

        // initialize output args - pass back the same data we got
        $this->outargs[CONFIGWIZARD_PASSBACK_DATA] = $this->inargs;


        switch ($this->mode) {
            case CONFIGWIZARD_MODE_GETSTAGE1HTML:
                $this->getstaget1html($output);
                break;

            case CONFIGWIZARD_MODE_VALIDATESTAGE1DATA:
                $this->validatestage1data($output);
                break;

            case CONFIGWIZARD_MODE_GETSTAGE2HTML:
                $this->getstaget2html($output);
                break;

            case CONFIGWIZARD_MODE_VALIDATESTAGE2DATA:
                $this->validatestage2data($output);
                break;

            case CONFIGWIZARD_MODE_GETSTAGE3HTML:
                $this->getstaget3html($output);
                break;

            case CONFIGWIZARD_MODE_VALIDATESTAGE3DATA:
                $this->validatestage3data($output);
                break;

            case CONFIGWIZARD_MODE_GETFINALSTAGEHTML:
                $this->getfinalstagehtml($output);
                break;

            case CONFIGWIZARD_MODE_GETOBJECTS:
                $this->getobjects($output);
                break;

            default:
                break;
        }

        return $output;
    }
}

switch (CONFIGWIZARD_API_VERSION) {
    case 2:
    case 3:

    /**
     * @param string $mode
     * @param null   $inargs
     * @param        $outargs
     * @param        $result
     *
     * @return mixed
     */
        function ssh_expect_static_configwizard_func($mode = "",
                                                     $inargs = null, &$outargs, &$result)
        {
            return ssh_expect_static_configwizard::configwizard_func($mode,
                $inargs, $outargs, $result);
        }

    /**
     * Class ssh_expect_static_configwizard
     */
    class ssh_expect_static_configwizard
        {

            protected static $name;
            public static $mode;
            public static $inargs;
            public static $outargs;
            public static $result;
            public static $args;

            public static $obj;

            public static function configwizard_init()
            {
                self::$obj = new ssh_expect_object_configwizard();
                self::$name = ssh_expect_object_configwizard::name;
                self::$mode =& self::$obj->mode;
                self::$inargs =& self::$obj->inargs;
                self::$outargs =& self::$obj->outargs;
                self::$result =& self::$obj->result;
                self::$args =& self::$obj->args;
                $ret = self::$obj->configwizard_init();

                // if(CONFIGWIZARD_API_VERSION===2)
                register_configwizard(self::$name, self::$args);

                return $ret;
            }

            /**
             * @param string $mode
             * @param null   $inargs
             * @param        $outargs
             * @param        $result
             *
             * @return mixed
             */
            public static function configwizard_func($mode = "",
                                                     $inargs = null, &$outargs, &$result)
            {
                return self::$obj->configwizard_func($mode,
                    $inargs, $outargs, $result);
            }

        }

        // run the initialization function
        ssh_expect_static_configwizard::configwizard_init();

        break;
    case 4:
        $configwizards[] = new ssh_expect_object_configwizard();
        break;
}
?>
